@@ -7,8 +7,7 @@
 #' 
 #' @param xlim limits for the x axis
 #' @param ylim limits for the y axis
-#' @param wise If \code{TRUE} will wisely expand the actual range of the plot
-#'   a little, in the way that setting the limits on the scales does
+#' @param wise deprecated in 0.9.1
 #' @export
 #' @examples 
 #' # There are two ways of zooming the plot display: with scales or 
@@ -38,9 +37,10 @@
 #' # When zooming the coordinate system, we see a subset of original 50 bins, 
 #' # displayed bigger
 #' d + coord_cartesian(xlim = c(0, 2))
-coord_cartesian <- function(xlim = NULL, ylim = NULL, wise = FALSE) {
-  coord(limits = list(x = xlim, y = ylim), wise = wise, 
-    subclass = "cartesian")
+coord_cartesian <- function(xlim = NULL, ylim = NULL, wise = NULL) {
+  if (!is.null(wise))
+    warning("Deprecated: wise argument to coord_cartesian is ignored", call. = FALSE)
+  coord(limits = list(x = xlim, y = ylim), subclass = "cartesian")
 }
 
 #' @S3method is.linear cartesian
@@ -63,48 +63,27 @@ coord_transform.cartesian <- function(., data, details) {
 
 #' @S3method coord_train cartesian
 coord_train.cartesian <- function(coord, scales) {
-  c(train_cartesian(scales$x, coord$limits$x, "x", coord$wise),
-    train_cartesian(scales$y, coord$limits$y, "y", coord$wise))
+  c(train_cartesian(scales$x, coord$limits$x, "x"),
+    train_cartesian(scales$y, coord$limits$y, "y"))
 }
 
-train_cartesian <- memoise(function(scale, limits, name, wise) {
-  # range is the limits in data space
+train_cartesian <- memoise(function(scale, limits, name) {
+
+  # first, calculate the range that is the numerical limits in data space
+
+  # expand defined by scale OR coord
   if (is.null(limits)) {
-    range <- scale_dimension(scale)
+    expand <- coord_expand_defaults(coord, scale)
+    range <- scale_dimension(scale, expand)
   } else {
     range <- range(scale_transform(scale, limits))
-    if (wise) {
-      scale$limits <- limits
-      range <- expand_range(range, scale$expand[1], scale$expand[2])
-    }
   }
 
-  # major and minor values in data space
-  major_v <- scale_break_positions(scale)
-  minor_v <- scale_breaks_minor_positions(scale)
-  
-  # if the scale is continuous, drop out-of-range values
-  if (inherits(scale, "continuous")) {
-    major_inside_range <- range[1] <= major_v  & major_v <= range[2]
-    major_inside_range <- major_inside_range & !is.na(major_inside_range)
-    minor_inside_range <- range[1] <= minor_v  & minor_v <= range[2]
-    minor_inside_range <- minor_inside_range & !is.na(minor_inside_range)
-  } else {
-    major_inside_range <- TRUE
-    minor_inside_range <- TRUE
-  }
-
-  # major and minor values in plot space
-  major <- rescale(major_v[major_inside_range], from = range)
-  minor <- rescale(minor_v[minor_inside_range], from = range)
-  labels <- scale_labels(scale)[major_inside_range]
-  
-  out <- list(range = range, major = major, minor = minor, labels = labels)
+  out <- scale_break_info(scale, range)
   names(out) <- paste(name, names(out), sep = ".")
   out
 })
 
-
 icon.cartesian <- function(.) {
   gTree(children = gList(
     segmentsGrob(c(0, 0.25), c(0.25, 0), c(1, 0.25), c(0.25, 1), gp=gpar(col="grey50", lwd=0.5)),
