@@ -47,8 +47,7 @@ coord_map <- function(projection="mercator", ..., orientation = NULL, xlim = NUL
   coord(
     projection = projection, 
     orientation = orientation,
-    xlim = xlim,
-    ylim = ylim,
+    limits = list(x = xlim, y = ylim),
     params = list(...),
     subclass = "map"
   )
@@ -84,54 +83,54 @@ coord_aspect.map <- function(coord, ranges) {
 
 #' @S3method coord_train map
 coord_train.map <- function(coord, scales) {
-  x.range <- coord$xlim %||% scale_dimension(scales$x)
-  y.range <- coord$ylim %||% scale_dimension(scales$y)
-  orientation <- coord$orientation %||% c(90, 0, mean(x.range))
+
+  # range in scale
+  ranges <- list()
+  for (n in c("x", "y")) {
+    
+    scale <- scales[[n]]
+    limits <- coord$limits[[n]]
+    
+    if (is.null(limits)) {
+      expand <- coord_expand_defaults(coord, scale, n)
+      range <- scale_dimension(scale, expand)
+    } else {
+      range <- range(scale_transform(scale, limits))
+    }
+    ranges[[n]] <- range
+  }
+  
+  orientation <- coord$orientation %||% c(90, 0, mean(ranges$x))
 
   # Increase chances of creating valid boundary region
   grid <- expand.grid(
-    x = seq(x.range[1], x.range[2], length = 50),
-    y = seq(y.range[1], y.range[2], length = 50)
+    x = seq(ranges$x[1], ranges$x[2], length = 50),
+    y = seq(ranges$y[1], ranges$y[2], length = 50)
   )
-  range <- mproject(coord, grid$x, grid$y, orientation)$range
 
-  # major and minor values in data space
-  x.proj <- range[1:2]
-  x.major <- scale_breaks(scales$x)
-  x.minor <- scale_breaks_minor(scales$x)
-  x.labels <- scale_labels(scales$x, x.major)
+  ret <- list(x = list(), y = list())
 
-  y.proj <- range[3:4]
-  y.major <- scale_breaks(scales$y)
-  y.minor <- scale_breaks_minor(scales$y)
-  y.labels <- scale_labels(scales$y, y.major)
-
-  # if the scale is continuous, drop out-of-range values
-  if (inherits(scales$x, "continuous")) {
-    major_inside_range <- x.range[1] <= x.major & x.major <= x.range[2]
-    major_inside_range <- major_inside_range & !is.na(major_inside_range)
-    minor_inside_range <- x.range[1] <= x.minor  & x.minor <= x.range[2]
-    minor_inside_range <- minor_inside_range & !is.na(minor_inside_range)
-    x.major <- x.major[major_inside_range]
-    x.minor <- x.major[minor_inside_range]
-    x.labels <- x.labels[major_inside_range]
-  }
-  if (inherits(scales$y, "continuous")) {
-    major_inside_range <- y.range[1] <= y.major & y.major <= y.range[2]
-    major_inside_range <- major_inside_range & !is.na(major_inside_range)
-    minor_inside_range <- y.range[1] <= y.minor  & y.minor <= y.range[2]
-    minor_inside_range <- minor_inside_range & !is.na(minor_inside_range)
-    y.major <- y.major[major_inside_range]
-    y.minor <- y.major[minor_inside_range]
-    y.labels <- y.labels[major_inside_range]
+  # range in map
+  proj <- mproject(coord, grid$x, grid$y, orientation)$range
+  ret$x$proj <- proj[1:2]
+  ret$y$proj <- proj[3:4]
+  
+  for (n in c("x", "y")) {
+    out <- scale_break_info(scales[[n]], ranges[[n]])
+    ret[[n]]$range <- out$range
+    ret[[n]]$major <- out$major_source
+    ret[[n]]$minor <- out$minor_source
+    ret[[n]]$labels <- out$labels
   }
 
-  list(
-    x.range = x.range, y.range = y.range, orientation = orientation,
-    x.proj = x.proj, y.proj = y.proj,
-    x.major = x.major, x.minor = x.minor, x.labels = x.labels,
-    y.major = y.major, y.minor = y.minor, y.labels = y.labels
+  details <- list(
+    orientation = orientation,
+    x.range = ret$x$range, y.range = ret$y$range,
+    x.proj = ret$x$proj, y.proj = ret$y$proj,
+    x.major = ret$x$major, x.minor = ret$x$minor, x.labels = ret$x$labels,
+    y.major = ret$y$major, y.minor = ret$y$minor, y.labels = ret$y$labels
   )
+  details
 }
 
 #' @S3method coord_render_bg map
@@ -150,31 +149,46 @@ coord_render_bg.map <- function(coord, details, theme) {
   xlines <- coord_transform(coord, xgrid, details)
   ylines <- coord_transform(coord, ygrid, details)
 
-  ggname("grill", grobTree(
-    theme_render(theme, "panel.background"),
-    theme_render(
+  if (nrow(xlines) > 0) {
+    grob.xlines <- theme_render(
       theme, "panel.grid.major", name = "x", 
       xlines$x, xlines$y, default.units = "native"
-    ),
-    theme_render(
+    )
+  } else {
+    grob.xlines <- zeroGrob()
+  }
+
+  if (nrow(ylines) > 0) {
+    grob.ylines <- theme_render(
       theme, "panel.grid.major", name = "y", 
       ylines$x, ylines$y, default.units = "native"
     )
+  } else {
+    grob.ylines <- zeroGrob()
+  }
+
+  ggname("grill", grobTree(
+    theme_render(theme, "panel.background"),
+    grob.xlines, grob.ylines
   ))
 }  
 
 #' @S3method coord_render_axis_h map
 coord_render_axis_h.map <- function(coord, details, theme) {
+  if (is.null(details$x.major)) return(zeroGrob())
+
   x_intercept <- with(details, data.frame(
     x = x.major,
     y = y.range[1]
   ))
   pos <- coord_transform(coord, x_intercept, details)
-  
+
   guide_axis(pos$x, details$x.labels, "bottom", theme)
 }
 #' @S3method coord_render_axis_v map
 coord_render_axis_v.map <- function(coord, details, theme) {
+  if (is.null(details$y.major)) return(zeroGrob())
+  
   x_intercept <- with(details, data.frame(
     x = x.range[1],
     y = y.major
