@@ -67,7 +67,7 @@ GeomVline <- proto(Geom, {
   
   icon <- function(.) linesGrob(c(0.5, 0.5), c(0, 1))
   default_stat <- function(.) StatVline
-  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = 1)
+  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = NA)
   guide_geom <- function(.) "vline"
 
   draw_legend <- function(., data, ...) {
